[![wercker status](https://app.wercker.com/status/b2638c861c69115d49ac9d9768d3186f/s/master "wercker status")](https://app.wercker.com/project/byKey/b2638c861c69115d49ac9d9768d3186f)

# Caitum Artificial Intelligence Toolkit


## License
This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
